@@ -6,8 +6,7 @@ knitr::opts_chunk$set(
 
 pkgs <- c(
   "datawizard",
-  "dplyr",
-  "htmltools"
+  "dplyr"
 )
 
 if (!all(vapply(pkgs, requireNamespace, quietly = TRUE, FUN.VALUE = logical(1L)))) {
@@ -17,19 +16,11 @@ if (!all(vapply(pkgs, requireNamespace, quietly = TRUE, FUN.VALUE = logical(1L))
 ## ----load, echo=FALSE, message=FALSE------------------------------------------
 library(datawizard)
 library(dplyr)
-library(htmltools)
 
 set.seed(123)
 iris <- iris[sample(nrow(iris), 10), ]
 row.names(iris) <- NULL
 
-row <- function(...) {
-  div(
-    class = "custom_note",
-    ...
-  )
-}
-
 ## -----------------------------------------------------------------------------
 data_select(iris, c("Sepal.Length", "Petal.Width"))
 
@@ -61,17 +52,6 @@ data_select(iris, contains("pal", "ec"))
 
 data_select(iris, regex("^Sep|ies"))
 
-## ----echo=FALSE---------------------------------------------------------------
-row("Note: these functions are not exported by `datawizard` but are detected and
-applied internally. This means that they won't be detected by autocompletion
-when we write them.")
-
-## ----echo=FALSE---------------------------------------------------------------
-row("Note #2: because these functions are not exported, they will not create
-conflicts with the ones that come from the `tidyverse` and that have the same name.
-So we can still use `dplyr` and its friends, it won't change anything for selection
-in `datawizard` functions!")
-
 ## -----------------------------------------------------------------------------
 data_select(iris, -c("Sepal.Length", "Petal.Width"))
 
@@ -92,13 +72,13 @@ data_select(iris, exclude = starts_with("Sep", "Peta"))
 
 ## -----------------------------------------------------------------------------
 my_function <- function(data, selection) {
-  find_columns(data, select = selection)
+  extract_column_names(data, select = selection)
 }
 my_function(iris, "Sepal.Length")
 my_function(iris, starts_with("Sep"))
 
 my_function_2 <- function(data, pattern) {
-  find_columns(data, select = starts_with(pattern))
+  extract_column_names(data, select = starts_with(pattern))
 }
 my_function_2(iris, "Sep")
 
